---
feature_story: FS_86_73_43_45
feature_title: server control scripts
feature_status: TODO
---

This feature provides standard framework-supported server control scripts written in Python (for greater test-ability):
*   start
*   stop
*   wait to start
*   wait to stop
*   check (see also FS_36_17_84_44 check script)

